library(scales)

setwd("C:/Users/USER/Desktop/7234925/") # working directory has to be adapted after file download
dat<-read.table('S1_Data2.txt',header=T, sep='\t'); head(dat) # data frame of 250 suitable articles with 510 unique P-values (rows), 'no' is the number of the article
# extract the P-values that were reported to at least 2 decimal numbers
dat<-dat[which(nchar(as.character(dat$textP))>4),]
# round all the P-values to 2 decimal places
dat$P.round<-round(dat$P.value, 2)

#---- exact binomial test ----
# testing whether the 4 articles with significant finding are fewer than the predicted 5%
binom.test(4, 246, p=0.05, alternative = "less")
# the same, but taking only 2 articles because the other two contained also other tests that were not significant
binom.test(2, 246, p=0.05, alternative = "less")

#---- randomly select from multiple values ----
# create a dummy data frame
set.seed(66)
IDp<-expand.grid(ID = levels(factor(dat$no)), P.value = 0); head(IDp)
IDp$ID<-as.numeric(as.character(IDp$ID))

#---- p-curve frequency - points ----
# creating first vector of one P-value per article for the background
y<-0
for (i in IDp$ID){
  y<-y+1
  if (length(which(dat$no==i))>1){
    # if more P-values with the same article number are present, then randomly order them and select the first element in the vector
    x<- sample(dat$P.round[dat$no==i])[1]
  }
  else {
    # if one P-value is present add it to the vector
    x<- dat$P.round[dat$no==i]
  }
  # add a row of 'no' and x to the data frame
  IDp$P.value[y]<-x
}

#plotting the distribution of P-value sampled one per article (Figure 1c) ----
hist10<-hist(IDp$P.value,20, right=T, plot=F)
Pbreak<-hist10$breaks-0.025
Pcount<-hist10$counts
plot(Pcount~Pbreak[2:21], las=1, xlab='P-value', ylab='Frequency', xlim=0:1, ylim=c(0,20), type='n', pch=16, axes=F)
axis(1, at=seq(0,1.0,0.1), labels=seq(0,1.0,0.1)); axis(2, las=1)
#chtres<-NA
Btest.P<-NA
pcnt<-rep(1,20)
pmed<-NA
pmed<-as.data.frame(rbind(pcnt))
names(pmed)<-Pbreak[2:21]
# repeating 500-times the random selection of the P-value set by sampling only one P-value per article
set.seed(66)
for (g in 1:500){
  y<-0
  for (i in IDp$ID){
    y<-y+1
    if (length(which(dat$no==i))>1){
      # if more P-values with the same article number are present, then randomly order them and select the first element in the vector
      x<- sample(dat$P.round[dat$no==i])[1]
    }
    else {
      # if one P-value is present add it to the vector
      x<- dat$P.round[dat$no==i]
    }
    # add a row of 'no' and x to the data frame
    IDp$P.value[y]<-x
  }
  hist10<-hist(IDp$P.value,20,right=T, plot=F)
  Pbreak<-hist10$breaks-0.025
  Pcount<-hist10$counts
  # drawing the fading points for this set of P-values
  points(Pcount~Pbreak[2:21], col=alpha(2,0.01), pch=16)
  # creating a matrix of the counts per each bit (20 collumns) from all the generated P-value sets (500 rows)
  pmed[g,]<-Pcount
  # testing whether the number of P-values in the 0.05 to <0.10 bin is larger than in the adjacent 0.10 to <0.15 bin (50% chance)
  Btest<-binom.test(Pcount[2:3],p=0.5, alternative = "greater")
  Btest.P[g]<-Btest$p.value
}

# getting the median numbers for distribution in the bins from the 500 sets
pval<-NA
for (i in 1:20){pval[i]<-median(pmed[,i])}
# the summary statistics for the binomial tests in the 500 sets
summary(Btest.P)
sd(Btest.P)

# idealised expected line of even P-value distribution in the bins
curve(x*0+188/20, lty=1, col=2, lwd=4, add=T)
lines(pval~Pbreak[2:21], lwd=4)
points(pval~Pbreak[2:21], col=1, pch=21, bg=2, lwd=4, cex=1)
text (0.22,19.5, 'C) collected data', cex=1.5)

#plotting the Selection bias scenario (Figure 1A) ----
plot(Pcount~Pbreak[2:21], las=1, xlab='P-value', ylab='Frequency', xlim=0:1, ylim=c(0,20), type='n', pch=16, axes=F)
axis(1, at=seq(0,1.0,0.1), labels=seq(0,1.0,0.1)); axis(2, las=1)
rect(0,0,0.05,18, col=8, border=NA)
curve(x*0+188/20, lty=1, col=2, lwd=4, add=T)
pval<-c(4, 10, 9, 10, 10, 9, 10, 9, 9, 10, 10, 9, 10, 10, 10, 9, 10, 10, 10, 10)
text (0.22,19.5, 'A) selection bias', cex=1.5)
lines(pval~Pbreak[2:21], lwd=4)
points(pval~Pbreak[2:21], col=1, pch=21, bg=0, lwd=4, cex=1)

#plotting the Reverse P-hacking scenario (Figure 1B) ----
plot(Pcount~Pbreak[2:21], las=1, xlab='P-value', ylab='Frequency', xlim=0:1, ylim=c(0,20), type='n', pch=16, axes=F)
axis(1, at=seq(0,1.0,0.1), labels=seq(0,1.0,0.1)); axis(2, las=1)
rect(0.05,0,0.15,18, col=8, border=NA)
curve(x*0+188/20, lty=1, col=2, lwd=4, add=T)
pval<-c(4, 16, 10, 9, 10, 9, 10, 9, 9, 9, 10, 8, 9, 9, 10, 9, 10, 9, 10, 9)
text (0.28,19.5, 'B) reverse P-hacking', cex=1.5)
lines(pval~Pbreak[2:21], lwd=4)
points(pval~Pbreak[2:21], col=1, pch=21, bg=0, lwd=4, cex=1)
